# Changelog

## [0.7.1](https://github.com/a2anet/a2a-utils/compare/a2a-utils-python-v0.7.0...a2a-utils-python-v0.7.1) (2026-04-09)


### Bug Fixes

* enforce UUID IDs and HTTPS file URI validation in `A2ASession`, `LocalFileStore`, and `JSONTaskStore` ([#12](https://github.com/a2anet/a2a-utils/issues/12)) ([6cab2c9](https://github.com/a2anet/a2a-utils/commit/6cab2c9ccecbe8cd67a4459fd9592e5a2889c915))

## [0.7.0](https://github.com/a2anet/a2a-utils/compare/a2a-utils-python-v0.5.0...a2a-utils-python-v0.7.0) (2026-04-07)


### Features

* add `A2ATools.tools` to Python and JavaScript ([#9](https://github.com/a2anet/a2a-utils/issues/9)) ([eeff113](https://github.com/a2anet/a2a-utils/commit/eeff1139a1cb8c9ea09e46c535d21dc55e4ca22d))

## [0.5.0](https://github.com/a2anet/a2a-utils/compare/a2a-utils-python-v0.4.0...a2a-utils-python-v0.5.0) (2026-04-03)


### Features

* add data and files parameters to A2ASession and A2ATools, save files in Messages ([cdae897](https://github.com/a2anet/a2a-utils/commit/cdae89795dfb3962482a2ee6f14dd62998973d83))


### Documentation

* add "Features" section to Python/JavaScript README.md ([f035207](https://github.com/a2anet/a2a-utils/commit/f0352079273ccd6fb977a8efc4f3b02552fe14b1))

## [0.4.0](https://github.com/a2anet/a2a-utils/compare/a2a-utils-python-v0.3.0...a2a-utils-python-v0.4.0) (2026-03-26)


### Features

* rename AgentManager to A2AAgents for consistent API naming ([#4](https://github.com/a2anet/a2a-utils/issues/4)) ([435fb71](https://github.com/a2anet/a2a-utils/commit/435fb71188c53ee5d72fb9e195d30e3f92e03449))

## [0.3.0](https://github.com/a2anet/a2a-utils/compare/a2a-utils-python-v0.2.0...a2a-utils-python-v0.3.0) (2026-03-24)


### Features

* **python:** add A2ATools with LLM-friendly tools for agent frameworks ([bb6b482](https://github.com/a2anet/a2a-utils/commit/bb6b48290ef328e4703c5dc492f36bcf3540c138))
* **python:** add get_task monitoring, configurable timeouts, and get_agent_card_from_url ([8568a8f](https://github.com/a2anet/a2a-utils/commit/8568a8f3048891c23d013d71661307b71b763555))


### Bug Fixes

* **python:** pass custom headers when fetching agent cards and surface init errors ([9a50c5f](https://github.com/a2anet/a2a-utils/commit/9a50c5fc4ca87a35c12369b18b834ba5b1604d15))


### Documentation

* write monorepo README, move "Design Decisions" section into it ([8252771](https://github.com/a2anet/a2a-utils/commit/82527714b8ff9803496a811656fcdba8a54d814d))

## [0.2.0](https://github.com/a2anet/a2a-utils/compare/a2a-utils-python-v0.1.0...a2a-utils-python-v0.2.0) (2026-03-18)


### Features

* initialize project from python-javascript-template ([2991fed](https://github.com/a2anet/a2a-utils/commit/2991fed3124516fb34eebecc619549fe64f13a2e))
* **python:** add A2ASession, AgentManager, TextArtifacts, DataArtifacts, FileStore, JSONTaskStore, and LLM-friendly A2A types ([96a930b](https://github.com/a2anet/a2a-utils/commit/96a930ba35eabef9e6ddf4aa3a18a7f2f30d2b2e))
* **python:** add py.typed marker for PEP 561 compliance ([d1a910c](https://github.com/a2anet/a2a-utils/commit/d1a910c43fe6254475f4434ed441e3a8ccfd792c))
